@@ -36,6 +36,10 @@ class AwsAPI(BaseObject):
             craigtrim@gmail.com
             *   pass keys as parameters
                 https://github.com/craigtrim/awsfile-helper/issues/4
+        Updated:
+            17-Nov-2022
+            craigtrim@gmail.com
+            *   add additional logging statements
 
         Args:
             aws_access_key (str, Optional): Encrypted AWS Access Key
@@ -74,6 +78,13 @@ class AwsAPI(BaseObject):
         Returns:
             dict: a dictionary of file contents keyed by file name
         """
+        if self.isEnabledForDebug:
+            self.logger.debug('\n'.join([
+                'Reading Files',
+                f'\tBucket Name: {bucket_name}',
+                f'\tFile Name: {file_name}',
+                f'\tLoad Files? {load_files}']))
+
         return self._read_files(
             file_name=file_name,
             bucket_name=bucket_name,
@@ -91,6 +102,12 @@ class AwsAPI(BaseObject):
         Returns:
             dict: a dictionary of file paths keyed by file name
         """
+        if self.isEnabledForDebug:
+            self.logger.debug('\n'.join([
+                'Downloading Files',
+                f'\tBucket Name: {bucket_name}',
+                f'\tFile Name: {file_name}']))
+
         return self._download_files(
             file_name=file_name,
             bucket_name=bucket_name)
@@ -110,6 +127,12 @@ class AwsAPI(BaseObject):
             str or None: the latest version
                 e.g., '0.1.2'
         """
+        if self.isEnabledForDebug:
+            self.logger.debug('\n'.join([
+                'Finding Latest Version Number',
+                f'\tBucket Name: {bucket_name}',
+                f'\tFile Name: {file_name}']))
+
         return self._find_latest_version_number(
             bucket_name=bucket_name,
             file_name=file_name)
@@ -147,6 +170,14 @@ class AwsAPI(BaseObject):
                 bucket_name=bucket_name,
                 file_name=file_name)
 
+        if self.isEnabledForDebug:
+            self.logger.debug('\n'.join([
+                'Finding File By Version',
+                f'\tBucket Name: {bucket_name}',
+                f'\tFile Name: {file_name}',
+                f'\tFile Ext: {file_ext}',
+                f'\tVersion: {version}']))
+
         return self._find_file_by_version(
             bucket_name=bucket_name,
             file_name=file_name,
