@@ -23,6 +23,18 @@ class FileContentReader(BaseObject):
     def process(self,
                 file_path: str,
                 file_ext: str) -> object:
+        """ Entry Point
+
+        Args:
+            file_path (str): the absolute path to the file
+            file_ext (str): the file extension
+
+        Raises:
+            NotImplementedError: Unrecognized File Extension
+
+        Returns:
+            object: the file contents
+        """
 
         if file_ext in ['yaml', 'yml']:
             return FileIO.read_yaml(file_path)
