@@ -31,7 +31,7 @@ class FindFileByVersion(BaseObject):
 
         Args:
             bucket_name (str): the name of the bucket
-                e.g., iceberg-data-core
+                e.g., name-of-bucket
             file_name (str): the qualified name of the file
                 e.g., 'training/myeliza/doctor'
             file_ext (str): the file extension
