@@ -4,6 +4,7 @@
 
 import os
 
+from baseblock import EnvIO
 from baseblock import FileIO
 from baseblock import Enforcer
 from baseblock import Stopwatch
@@ -20,41 +21,15 @@ class ReadFromCache(BaseObject):
             6-Aug-2022
             craigtrim@gmail.com
             *   https://bast-ai.atlassian.net/browse/COR-72
+        Updated:
+            1-Nov-2022
+            craigtrim@gmail.com
+            *   retrieve local directory from environment
+                https://github.com/craigtrim/awsfile-helper/issues/3
         """
         BaseObject.__init__(self, __name__)
-
-    @staticmethod
-    def _construct_local_path(file_path: str) -> str:
-        if file_path:
-            FileIO.exists_or_create(file_path)
-            return file_path
-        return FileIO.local_directory_by_name('Graffl')
-
-    # @staticmethod
-    # # TODO: replace with baseblock function in 0.1.5
-    # def normpath(path: str) -> str:
-    #     """ Normalize Path to use forward slashes
-
-    #     This differs from
-    #         os.path.normpath
-    #     in that the Python std lib call will normalize on a platform-specific basis
-
-    #     This means a path like this
-    #         alpha/bravo/charlie
-    #     will become
-    #         alpha\\bravo\\charlie
-    #     on a Windows platform; which is silly, because forward slashes work just fine on Windows
-
-    #     Args:
-    #         path (str): the incoming path
-
-    #     Returns:
-    #         str: the outgoing path
-    #     """
-    #     if '\\' in path:
-    #         path = path.replace('\\', '/')
-    #         os.path.normpath
-    #     return path
+        self._local_directory = FileIO.local_directory_by_name(
+            EnvIO.str_or_default('LOCAL_DIRECTORY_NAME', 'AWSFileHelper'))
 
     def process(self,
                 file_name: str,
@@ -71,15 +46,17 @@ class ReadFromCache(BaseObject):
         file_path = file_name
         file_name = f"{file_name.split('/')[-1]}-{file_version}.{file_ext}"
 
-        cached_copy = FileIO.join(
-            FileIO.local_directory_by_name('Graffl'),
-            file_path, file_version, file_name)
+        cached_copy = FileIO.join(self._local_directory,
+                                  file_path,
+                                  file_version,
+                                  file_name)
 
         if FileIO.exists(cached_copy):
 
             if self.isEnabledForDebug:
                 self.logger.debug('\n'.join([
                     'Cached Read Completed',
+                    f'\tLocal Directory: {self._local_directory}',
                     f'\tFile Name: {file_name}',
                     f'\tTotal Time: {str(sw)}',
                     '\tTotal Files: 1']))
